#
# spec file for package itpp
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   8
%define libname lib%{name}%{sover}
Name:           itpp
Version:        4.3.1
Release:        bp153.1.18
Summary:        C++ library of math, signal processing and communication routines
License:        GPL-3.0-only
Group:          Development/Libraries/C and C++
URL:            http://itpp.sourceforge.net/
Source:         https://sourceforge.net/projects/itpp/files/itpp/%{version}/itpp-%{version}.tar.bz2
Patch0:         libitpp-4.0.7-namespace.patch
Patch1:         gtest_support.patch
#PATCH-FIX-UPSTREAM memmove.patch [deb#741814] cristeab@gmail.com -- Corrected multilateration algorithm
Patch2:         itpp-4.3.1_memmove.patch
# PATCH-FIX-UPSTREAM itpp-respect_dlib_suffix.diff mardnh@gmx.de -- http://sourceforge.net/p/itpp/bugs/236/
Patch3:         itpp-respect_dlib_suffix.diff
# PATCH-FIX-UPSTREAM itpp-reproducible.patch bmwiedemann -- https://sourceforge.net/p/itpp/git/merge-requests/3/
Patch4:         itpp-reproducible.patch
BuildRequires:  blas-devel
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  fftw3-threads
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  ghostscript
BuildRequires:  googletest-devel
BuildRequires:  lapack-devel
BuildRequires:  pkgconfig
BuildRequires:  texlive-latex
BuildRequires:  pkgconfig(fftw3)

%description
IT++ is a C++ library of mathematical, signal processing and
communication classes and functions. Its main use is in simulation of
communication systems and for performing research in the area of
communications. The kernel of the library consists of generic vector and
matrix classes, and a set of accompanying routines. Such a kernel makes
IT++ similar to MATLAB or GNU Octave.

%package -n %{libname}
Summary:        C++ library of math, signal processing and communication routines
Group:          System/Libraries

%description -n %{libname}
IT++ is a C++ library of mathematical, signal processing and
communication classes and functions. Its main use is in simulation of
communication systems and for performing research in the area of
communications. The kernel of the library consists of generic vector and
matrix classes, and a set of accompanying routines. Such a kernel makes
IT++ similar to MATLAB or GNU Octave.

%package devel
Summary:        Header files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       blas-devel
Requires:       lapack-devel
Requires:       pkgconfig(fftw3)
Provides:       %{libname}-devel = %{version}
Obsoletes:      %{libname}-devel < %{version}

%description devel
Theis package contains the header files for the IT++ library contained in %{name}%{sonum}

IT++ is a C++ library of mathematical, signal processing and
communication classes and functions. Its main use is in simulation of
communication systems and for performing research in the area of
communications. The kernel of the library consists of generic vector and
matrix classes, and a set of accompanying routines. Such a kernel makes
IT++ similar to MATLAB or GNU Octave.

%package doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML
Requires:       %{libname} = %{version}

%description doc
This package contains the documentation for the IT++ as html and man pages.

IT++ is a C++ library of mathematical, signal processing and
communication classes and functions. Its main use is in simulation of
communication systems and for performing research in the area of
communications. The kernel of the library consists of generic vector and
matrix classes, and a set of accompanying routines. Such a kernel makes
IT++ similar to MATLAB or GNU Octave.

%prep
%setup -q
%patch0
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1

%build
%cmake \
  -DGTEST_DIR=%{_includedir}/gtest \
  -DLAPACK_LIBRARIES=%{_libdir}/liblapack.so.3 \
  -DCMAKE_BUILD_TYPE=Release
%make_jobs

%check
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
build/gtests/itpp_gtests |:

%install
%cmake_install
# move docs to /usr/share/doc/packages
mkdir -p %{buildroot}%{_docdir}
mv -t %{buildroot}%{_docdir}/ %{buildroot}%{_datadir}/doc/%{name}
rm %{buildroot}%{_docdir}/%{name}/html/*.log
# find dupes in docs
%fdupes -s %{buildroot}%{_docdir}

%post   -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{sover}*

%files devel
%{_bindir}/%{name}-config
%{_mandir}/man1/%{name}-config*
%{_datadir}/%{name}
%{_includedir}/%{name}
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/lib%{name}.so

%files doc
%{_docdir}/%{name}

%changelog
* Thu Apr 11 2019 Martin Pluskal <mpluskal@suse.com>
- Fix licensing information
* Thu Mar 21 2019 Martin Pluskal <mpluskal@suse.com>
- Fix  building - boo#1129920
* Thu Sep 14 2017 bwiedemann@suse.com
- Add itpp-reproducible.patch to make build reproducible (boo#1047218)
- Drop latex .log file from doc dir for the same reason
* Thu Aug 24 2017 mpluskal@suse.com
- Update dependencies and drop rpmlintrc
* Sat Aug 12 2017 jengelh@inai.de
- RPM group fix. Remove stray Provides.
* Wed Aug  2 2017 mpluskal@suse.com
- Rename and cleanup package
* Sun Sep 20 2015 mardnh@gmx.de
- switched to %%cmake macro
- ran spec-cleaner
- add patch: itpp-respect_dlib_suffix.diff
* Sat Nov  1 2014 avvissu@yandex.ru
- Patch to fix build for 64bit:
  * use memmove instead of memcpy (itpp-4.3.1_memmove.patch)
* Thu Oct 17 2013 joschibrauchle@gmx.de
- update to version 4.3.1
* Thu May 10 2012 scorot@free.fr
- remove conditional BuildRequires for blas and lapack since
  recent lapack now build correctly for all suse version
* Sat Apr 14 2012 badshah400@gmail.com
- Update BuildRequires in keeping with lapack package naming
  changes.
* Mon Mar 26 2012 toddrme2178@gmail.com
- Clean up spec file formatting
- Fix 32bit package installation
* Sun Aug 21 2011 werner.ho@gmx.de
- new version 4.2
* Tue Sep 14 2010 prusnak@opensuse.org
- updated to 4.0.7
- fixed build (namespace.patch)
- spec cleanup
* Mon Dec 29 2008 werner.ho@gmx.de
- directory build fix for openSUSE 11.1
* Mon Oct 13 2008 dannoritzer@web.de
- new version 4.0.6
* Wed Aug 27 2008 dannoritzer@web.de
- cleaned up %%defines that affect older distro versions not build
  anymore
- adjusted description
* Mon Aug 18 2008 dannoritzer@web.de
- renamed package and split up to libitpp6, libitpp-devel, and libitpp-doc
* Thu Jul 31 2008 dannoritzer@web.de
- new version 4.0.5
* Mon Feb 25 2008 dannoritzer@web.de
- new version 4.0.3, no functional changes, just packaging issues with
  other distributions than openSUSE. Just bumping up this package to
  keep up with the revisions.
* Mon Feb 18 2008 dannoritzer@web.de
- new version 4.0.2
* Fri Dec 21 2007 dannoritzer@web.de
- added patch to build on 10.0 x86_64
* Mon Dec 17 2007 dannoritzer@web.de
- new version 4.0.1
* Sat Oct 20 2007 werner.ho@gmx.de
- removed blas/lapack-devel packages for newer distributions
* Mon Oct 15 2007 dannoritzer@web.de
- new version 4.0.0 stable release
- moved html folder under /usr/share/doc/packages/itpp
- took out mtune=i686 flag for i586 compilation with g77
- SUSE < 10.1 uses g77 again, as lapack does so,
- took out SUSE 9.3 requirements
* Tue Oct  9 2007 dannoritzer@web.de
- new version 4.0.0-rc2
- added debuginfo package
* Wed Aug 29 2007 dannoritzer@web.de
- new version 3.99.3.1
- added -DNDEBUG flag to take out debug macros
- added older NEWS and ChangeLog files
- changed Fortran compiler from g77 to gfortran
* Sun Jul 15 2007 dannoritzer@web.de
- initial package for development snapshot gearing towards 4.0
